# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKThresholdingPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkThresholdLabelerImageFilterPython
else:
    import _itkThresholdLabelerImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrix_fixedPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.itkVectorImagePython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterBPython

def itkThresholdLabelerImageFilterIF2IF2_Superclass_New():
    return itkThresholdLabelerImageFilterIF2IF2_Superclass.New()

class itkThresholdLabelerImageFilterIF2IF2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIF2IF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIF2IF2_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIF2IF2_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< float,float >
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< float,float > const &
        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ThresholdLabeler< float,float > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIF2IF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIF2IF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIF2IF2_Superclass

        Create a new object of the class itkThresholdLabelerImageFilterIF2IF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIF2IF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIF2IF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIF2IF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIF2IF2_Superclass in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Superclass_swigregister(itkThresholdLabelerImageFilterIF2IF2_Superclass)

def itkThresholdLabelerImageFilterIF3IF3_Superclass_New():
    return itkThresholdLabelerImageFilterIF3IF3_Superclass.New()

class itkThresholdLabelerImageFilterIF3IF3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIF3IF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIF3IF3_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIF3IF3_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< float,float >
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< float,float > const &
        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ThresholdLabeler< float,float > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIF3IF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIF3IF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIF3IF3_Superclass

        Create a new object of the class itkThresholdLabelerImageFilterIF3IF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIF3IF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIF3IF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIF3IF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIF3IF3_Superclass in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Superclass_swigregister(itkThresholdLabelerImageFilterIF3IF3_Superclass)

def itkThresholdLabelerImageFilterISS2ISS2_Superclass_New():
    return itkThresholdLabelerImageFilterISS2ISS2_Superclass.New()

class itkThresholdLabelerImageFilterISS2ISS2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkThresholdLabelerImageFilterISS2ISS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterISS2ISS2_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< short,short >
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< short,short > const &
        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ThresholdLabeler< short,short > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterISS2ISS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterISS2ISS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterISS2ISS2_Superclass

        Create a new object of the class itkThresholdLabelerImageFilterISS2ISS2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterISS2ISS2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterISS2ISS2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterISS2ISS2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterISS2ISS2_Superclass in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Superclass_swigregister(itkThresholdLabelerImageFilterISS2ISS2_Superclass)

def itkThresholdLabelerImageFilterISS3ISS3_Superclass_New():
    return itkThresholdLabelerImageFilterISS3ISS3_Superclass.New()

class itkThresholdLabelerImageFilterISS3ISS3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkThresholdLabelerImageFilterISS3ISS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterISS3ISS3_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< short,short >
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< short,short > const &
        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ThresholdLabeler< short,short > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterISS3ISS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterISS3ISS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterISS3ISS3_Superclass

        Create a new object of the class itkThresholdLabelerImageFilterISS3ISS3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterISS3ISS3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterISS3ISS3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterISS3ISS3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterISS3ISS3_Superclass in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Superclass_swigregister(itkThresholdLabelerImageFilterISS3ISS3_Superclass)

def itkThresholdLabelerImageFilterIUC2IUC2_Superclass_New():
    return itkThresholdLabelerImageFilterIUC2IUC2_Superclass.New()

class itkThresholdLabelerImageFilterIUC2IUC2_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIUC2IUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIUC2IUC2_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< unsigned char,unsigned char > const &
        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ThresholdLabeler< unsigned char,unsigned char > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIUC2IUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIUC2IUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIUC2IUC2_Superclass

        Create a new object of the class itkThresholdLabelerImageFilterIUC2IUC2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIUC2IUC2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIUC2IUC2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIUC2IUC2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIUC2IUC2_Superclass in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Superclass_swigregister(itkThresholdLabelerImageFilterIUC2IUC2_Superclass)

def itkThresholdLabelerImageFilterIUC3IUC3_Superclass_New():
    return itkThresholdLabelerImageFilterIUC3IUC3_Superclass.New()

class itkThresholdLabelerImageFilterIUC3IUC3_Superclass(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIUC3IUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIUC3IUC3_Superclass_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Superclass_Clone(self)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< unsigned char,unsigned char >
        GetFunctor(self) -> itk::Functor::ThresholdLabeler< unsigned char,unsigned char > const &
        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Superclass_GetFunctor(self, *args)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Functor::ThresholdLabeler< unsigned char,unsigned char > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Superclass_SetFunctor(self, functor)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIUC3IUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIUC3IUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIUC3IUC3_Superclass

        Create a new object of the class itkThresholdLabelerImageFilterIUC3IUC3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIUC3IUC3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIUC3IUC3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIUC3IUC3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIUC3IUC3_Superclass in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Superclass_swigregister(itkThresholdLabelerImageFilterIUC3IUC3_Superclass)

def itkThresholdLabelerImageFilterIF2IF2_New():
    return itkThresholdLabelerImageFilterIF2IF2.New()

class itkThresholdLabelerImageFilterIF2IF2(itkThresholdLabelerImageFilterIF2IF2_Superclass):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIF2IF2_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIF2IF2_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_Clone(self)
    PixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_PixelTypeComparable
    
    OutputPixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_OutputPixelTypeComparable
    
    OutputPixelTypeOStreamWritable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_OutputPixelTypeOStreamWritable
    

    def SetThresholds(self, thresholds):
        r"""
        SetThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< float,std::allocator< float > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_SetThresholds(self, thresholds)

    def GetThresholds(self):
        r"""GetThresholds(self) -> vectorF"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_GetThresholds(self)

    def SetRealThresholds(self, thresholds):
        r"""
        SetRealThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< double,std::allocator< double > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_SetRealThresholds(self, thresholds)

    def GetRealThresholds(self):
        r"""GetRealThresholds(self) -> vectorD"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_GetRealThresholds(self)

    def SetLabelOffset(self, _arg):
        r"""
        SetLabelOffset(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_SetLabelOffset(self, _arg)

    def GetLabelOffset(self):
        r"""GetLabelOffset(self) -> float"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_GetLabelOffset(self)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIF2IF2

        Create a new object of the class itkThresholdLabelerImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIF2IF2 in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF2IF2_swigregister(itkThresholdLabelerImageFilterIF2IF2)

def itkThresholdLabelerImageFilterIF3IF3_New():
    return itkThresholdLabelerImageFilterIF3IF3.New()

class itkThresholdLabelerImageFilterIF3IF3(itkThresholdLabelerImageFilterIF3IF3_Superclass):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIF3IF3_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIF3IF3_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_Clone(self)
    PixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_PixelTypeComparable
    
    OutputPixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_OutputPixelTypeComparable
    
    OutputPixelTypeOStreamWritable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_OutputPixelTypeOStreamWritable
    

    def SetThresholds(self, thresholds):
        r"""
        SetThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< float,std::allocator< float > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_SetThresholds(self, thresholds)

    def GetThresholds(self):
        r"""GetThresholds(self) -> vectorF"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_GetThresholds(self)

    def SetRealThresholds(self, thresholds):
        r"""
        SetRealThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< double,std::allocator< double > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_SetRealThresholds(self, thresholds)

    def GetRealThresholds(self):
        r"""GetRealThresholds(self) -> vectorD"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_GetRealThresholds(self)

    def SetLabelOffset(self, _arg):
        r"""
        SetLabelOffset(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_SetLabelOffset(self, _arg)

    def GetLabelOffset(self):
        r"""GetLabelOffset(self) -> float"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_GetLabelOffset(self)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIF3IF3

        Create a new object of the class itkThresholdLabelerImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIF3IF3 in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIF3IF3_swigregister(itkThresholdLabelerImageFilterIF3IF3)

def itkThresholdLabelerImageFilterISS2ISS2_New():
    return itkThresholdLabelerImageFilterISS2ISS2.New()

class itkThresholdLabelerImageFilterISS2ISS2(itkThresholdLabelerImageFilterISS2ISS2_Superclass):
    r"""Proxy of C++ itkThresholdLabelerImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterISS2ISS2_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterISS2ISS2_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_Clone(self)
    PixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_PixelTypeComparable
    
    OutputPixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_OutputPixelTypeComparable
    
    OutputPixelTypeOStreamWritable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_OutputPixelTypeOStreamWritable
    

    def SetThresholds(self, thresholds):
        r"""
        SetThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< short,std::allocator< short > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_SetThresholds(self, thresholds)

    def GetThresholds(self):
        r"""GetThresholds(self) -> vectorSS"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_GetThresholds(self)

    def SetRealThresholds(self, thresholds):
        r"""
        SetRealThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< double,std::allocator< double > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_SetRealThresholds(self, thresholds)

    def GetRealThresholds(self):
        r"""GetRealThresholds(self) -> vectorD"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_GetRealThresholds(self)

    def SetLabelOffset(self, _arg):
        r"""
        SetLabelOffset(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_SetLabelOffset(self, _arg)

    def GetLabelOffset(self):
        r"""GetLabelOffset(self) -> short"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_GetLabelOffset(self)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterISS2ISS2

        Create a new object of the class itkThresholdLabelerImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterISS2ISS2 in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS2ISS2_swigregister(itkThresholdLabelerImageFilterISS2ISS2)

def itkThresholdLabelerImageFilterISS3ISS3_New():
    return itkThresholdLabelerImageFilterISS3ISS3.New()

class itkThresholdLabelerImageFilterISS3ISS3(itkThresholdLabelerImageFilterISS3ISS3_Superclass):
    r"""Proxy of C++ itkThresholdLabelerImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterISS3ISS3_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterISS3ISS3_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_Clone(self)
    PixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_PixelTypeComparable
    
    OutputPixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_OutputPixelTypeComparable
    
    OutputPixelTypeOStreamWritable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_OutputPixelTypeOStreamWritable
    

    def SetThresholds(self, thresholds):
        r"""
        SetThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< short,std::allocator< short > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_SetThresholds(self, thresholds)

    def GetThresholds(self):
        r"""GetThresholds(self) -> vectorSS"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_GetThresholds(self)

    def SetRealThresholds(self, thresholds):
        r"""
        SetRealThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< double,std::allocator< double > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_SetRealThresholds(self, thresholds)

    def GetRealThresholds(self):
        r"""GetRealThresholds(self) -> vectorD"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_GetRealThresholds(self)

    def SetLabelOffset(self, _arg):
        r"""
        SetLabelOffset(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_SetLabelOffset(self, _arg)

    def GetLabelOffset(self):
        r"""GetLabelOffset(self) -> short"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_GetLabelOffset(self)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterISS3ISS3

        Create a new object of the class itkThresholdLabelerImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterISS3ISS3 in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterISS3ISS3_swigregister(itkThresholdLabelerImageFilterISS3ISS3)

def itkThresholdLabelerImageFilterIUC2IUC2_New():
    return itkThresholdLabelerImageFilterIUC2IUC2.New()

class itkThresholdLabelerImageFilterIUC2IUC2(itkThresholdLabelerImageFilterIUC2IUC2_Superclass):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIUC2IUC2_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIUC2IUC2_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_Clone(self)
    PixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_PixelTypeComparable
    
    OutputPixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_OutputPixelTypeComparable
    
    OutputPixelTypeOStreamWritable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_OutputPixelTypeOStreamWritable
    

    def SetThresholds(self, thresholds):
        r"""
        SetThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< unsigned char,std::allocator< unsigned char > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_SetThresholds(self, thresholds)

    def GetThresholds(self):
        r"""GetThresholds(self) -> vectorUC"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_GetThresholds(self)

    def SetRealThresholds(self, thresholds):
        r"""
        SetRealThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< double,std::allocator< double > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_SetRealThresholds(self, thresholds)

    def GetRealThresholds(self):
        r"""GetRealThresholds(self) -> vectorD"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_GetRealThresholds(self)

    def SetLabelOffset(self, _arg):
        r"""
        SetLabelOffset(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_SetLabelOffset(self, _arg)

    def GetLabelOffset(self):
        r"""GetLabelOffset(self) -> unsigned char"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_GetLabelOffset(self)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIUC2IUC2

        Create a new object of the class itkThresholdLabelerImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIUC2IUC2 in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC2IUC2_swigregister(itkThresholdLabelerImageFilterIUC2IUC2)

def itkThresholdLabelerImageFilterIUC3IUC3_New():
    return itkThresholdLabelerImageFilterIUC3IUC3.New()

class itkThresholdLabelerImageFilterIUC3IUC3(itkThresholdLabelerImageFilterIUC3IUC3_Superclass):
    r"""Proxy of C++ itkThresholdLabelerImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkThresholdLabelerImageFilterIUC3IUC3_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkThresholdLabelerImageFilterIUC3IUC3_Pointer"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_Clone(self)
    PixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_PixelTypeComparable
    
    OutputPixelTypeComparable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_OutputPixelTypeComparable
    
    OutputPixelTypeOStreamWritable = _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_OutputPixelTypeOStreamWritable
    

    def SetThresholds(self, thresholds):
        r"""
        SetThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< unsigned char,std::allocator< unsigned char > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_SetThresholds(self, thresholds)

    def GetThresholds(self):
        r"""GetThresholds(self) -> vectorUC"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_GetThresholds(self)

    def SetRealThresholds(self, thresholds):
        r"""
        SetRealThresholds(self, thresholds)

        Parameters
        ----------
        thresholds: std::vector< double,std::allocator< double > > const &

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_SetRealThresholds(self, thresholds)

    def GetRealThresholds(self):
        r"""GetRealThresholds(self) -> vectorD"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_GetRealThresholds(self)

    def SetLabelOffset(self, _arg):
        r"""
        SetLabelOffset(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_SetLabelOffset(self, _arg)

    def GetLabelOffset(self):
        r"""GetLabelOffset(self) -> unsigned char"""
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_GetLabelOffset(self)
    __swig_destroy__ = _itkThresholdLabelerImageFilterPython.delete_itkThresholdLabelerImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkThresholdLabelerImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkThresholdLabelerImageFilterIUC3IUC3

        Create a new object of the class itkThresholdLabelerImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkThresholdLabelerImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkThresholdLabelerImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkThresholdLabelerImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkThresholdLabelerImageFilterIUC3IUC3 in _itkThresholdLabelerImageFilterPython:
_itkThresholdLabelerImageFilterPython.itkThresholdLabelerImageFilterIUC3IUC3_swigregister(itkThresholdLabelerImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def unary_functor_image_filter(*args: itkt.ImageLike,  functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for UnaryFunctorImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.UnaryFunctorImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def unary_functor_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKThresholding.UnaryFunctorImageFilter
    unary_functor_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    unary_functor_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def threshold_labeler_image_filter(*args: itkt.ImageLike,  thresholds: Sequence[float]=..., real_thresholds: Sequence[float]=..., label_offset: float=..., functor=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ThresholdLabelerImageFilter"""
    import itk

    kwarg_typehints = { 'thresholds':thresholds,'real_thresholds':real_thresholds,'label_offset':label_offset,'functor':functor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ThresholdLabelerImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def threshold_labeler_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKThresholding.ThresholdLabelerImageFilter
    threshold_labeler_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    threshold_labeler_image_filter.__doc__ = filter_object.__doc__



